@@ -26,6 +26,10 @@ func init() {
 	registerCloudControl("AWS::AppRunner::Service")
 	registerCloudControl("AWS::ApplicationInsights::Application")
 	registerCloudControl("AWS::Backup::Framework")
+	registerCloudControl("AWS::ECR::PublicRepository")
+	registerCloudControl("AWS::ECR::PullThroughCacheRule")
+	registerCloudControl("AWS::ECR::RegistryPolicy")
+	registerCloudControl("AWS::ECR::ReplicationConfiguration")
 	registerCloudControl("AWS::MWAA::Environment")
 	registerCloudControl("AWS::Synthetics::Canary")
 	registerCloudControl("AWS::Timestream::Database")
