@@ -3,15 +3,17 @@ package resources
 import (
 	"fmt"
 	"strings"
+	"time"
 
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/emr"
+	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
 )
 
 type EMRCluster struct {
-	svc   *emr.EMR
-	ID    *string
-	state *string
+	svc     *emr.EMR
+	cluster *emr.ClusterSummary
+	state   *string
 }
 
 func init() {
@@ -32,9 +34,9 @@ func ListEMRClusters(sess *session.Session) ([]Resource, error) {
 
 		for _, cluster := range resp.Clusters {
 			resources = append(resources, &EMRCluster{
-				svc:   svc,
-				ID:    cluster.Id,
-				state: cluster.Status.State,
+				svc:     svc,
+				cluster: cluster,
+				state:   cluster.Status.State,
 			})
 		}
 
@@ -48,11 +50,17 @@ func ListEMRClusters(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
+func (f *EMRCluster) Properties() types.Properties {
+	properties := types.NewProperties().
+		Set("CreatedTime", f.cluster.Status.Timeline.CreationDateTime.Format(time.RFC3339))
+	return properties
+}
+
 func (f *EMRCluster) Remove() error {
 
 	//Call names are inconsistent in the SDK
 	_, err := f.svc.TerminateJobFlows(&emr.TerminateJobFlowsInput{
-		JobFlowIds: []*string{f.ID},
+		JobFlowIds: []*string{f.cluster.Id},
 	})
 	// Force nil return due to async callbacks blocking
 	if err == nil {
@@ -63,7 +71,7 @@ func (f *EMRCluster) Remove() error {
 }
 
 func (f *EMRCluster) String() string {
-	return *f.ID
+	return *f.cluster.Id
 }
 
 func (f *EMRCluster) Filter() error {
